/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.style.book.util.comparator;

import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.style.book.model.StyleBookEntry;

/**
 * @author Eudaldo Alonso
 */
public class StyleBookEntryNameComparator
	extends OrderByComparator<StyleBookEntry> {

	public static final String ORDER_BY_ASC = "StyleBookEntry.name ASC";

	public static final String ORDER_BY_DESC = "StyleBookEntry.name DESC";

	public static final String[] ORDER_BY_FIELDS = {"name"};

	public StyleBookEntryNameComparator() {
		this(false);
	}

	public StyleBookEntryNameComparator(boolean ascending) {
		_ascending = ascending;
	}

	@Override
	public int compare(
		StyleBookEntry styleBookEntry1, StyleBookEntry styleBookEntry2) {

		String name1 = StringUtil.toLowerCase(styleBookEntry1.getName());
		String name2 = StringUtil.toLowerCase(styleBookEntry2.getName());

		int value = name1.compareTo(name2);

		if (_ascending) {
			return value;
		}

		return -value;
	}

	@Override
	public String getOrderBy() {
		if (_ascending) {
			return ORDER_BY_ASC;
		}

		return ORDER_BY_DESC;
	}

	@Override
	public String[] getOrderByFields() {
		return ORDER_BY_FIELDS;
	}

	@Override
	public boolean isAscending() {
		return _ascending;
	}

	private final boolean _ascending;

}